@@ -1,4 +1,5 @@
 import logging
+import os
 import traceback
 
 from django.core.exceptions import ObjectDoesNotExist
@@ -6,6 +7,8 @@ from django.db import IntegrityError
 from django.http import JsonResponse
 
 
+DEBUG = os.getenv('DEBUG', 0)
+
 def report_exception(exc, level="warning"):
     # TODO add sentry settings
     try:
@@ -49,7 +52,10 @@ def exception_handler(exc, context):
         err_data = {
             "error": "Unknown error"
         }
+        if DEBUG:
+            err_data['tb'] = tb
         logging.error(exc)
+        logging.error(tb)
         report_exception(exc, "error")
         response = JsonResponse(err_data, safe=True, status=500)
 
